==> org.eclipse.n4js.ui.source_0.0.1.201901150401.jar: org/eclipse/n4js/ui/quickfix/AbstractN4JSQuickfixProvider.java <==
/**
 * Copyright (c) 2016 NumberFour AG.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *   NumberFour AG - Initial API and implementation
 */
package org.eclipse.n4js.ui.quickfix;

import com.google.inject.Inject;
import org.apache.log4j.Logger;
import org.eclipse.jface.text.contentassist.ICompletionProposal;
import org.eclipse.n4js.ts.ui.quickfix.TypesQuickfixProvider;
import org.eclipse.n4js.ui.changes.ChangeManager;
import org.eclipse.n4js.ui.quickfix.N4JSQuickfixProvider;
import org.eclipse.n4js.ui.quickfix.N4Modification;
import org.eclipse.n4js.ui.quickfix.N4ModificationWrapper;
import org.eclipse.xtext.ui.editor.model.edit.IModification;
import org.eclipse.xtext.ui.editor.model.edit.ISemanticModification;
import org.eclipse.xtext.ui.editor.quickfix.CompletionProposalBasedModification;
import org.eclipse.xtext.ui.editor.quickfix.IssueResolutionAcceptor;
import org.eclipse.xtext.validation.Issue;
import org.eclipse.xtext.xbase.lib.Exceptions;

@SuppressWarnings("all")
public class AbstractN4JSQuickfixProvider extends TypesQuickfixProvider {
  @Inject
  private ChangeManager changeManager;
  
  /**
   * Logger for this class
   */
  protected final static Logger logger = Logger.getLogger(N4JSQuickfixProvider.class);
  
  @Override
  public void createLinkingIssueResolutions(final Issue issue, final IssueResolutionAcceptor issueResolutionAcceptor) {
    try {
      super.createLinkingIssueResolutions(issue, issueResolutionAcceptor);
    } catch (final Throwable _t) {
      if (_t instanceof Exception) {
        final Exception e = (Exception)_t;
        AbstractN4JSQuickfixProvider.logger.error(e);
      } else {
        throw Exceptions.sneakyThrow(_t);
      }
    }
  }
  
  /**
   * Create an issue resolution based on an {@link N4Modification}. This should be used for most N4JS quick fixes.
   * <p>
   * Note how this method mimics the API in {@link IssueResolutionAcceptor}.
   */
  protected void accept(final IssueResolutionAcceptor acceptor, final Issue issue, final String label, final String description, final String image, final N4Modification modification) {
    N4ModificationWrapper _n4ModificationWrapper = new N4ModificationWrapper(modification, issue, this.changeManager);
    acceptor.accept(issue, label, description, image, _n4ModificationWrapper);
  }
  
  /**
   * This method allows to create quick fixes via the ordinary Xtext quick fix API that are based on an {@link ICompletionProposal}
   * instead of an {@link IModification}, {@link ISemanticModification} or {@link N4Modification}. It is only intended for work-around
   * cases, try to use {@link #accept(IssueResolutionAcceptor,Issue,String,String,String,N4Modification} instead.
   * <p>
   * Note how this method mimics the API in {@link IssueResolutionAcceptor}.
   */
  protected void accept(final IssueResolutionAcceptor acceptor, final Issue issue, final String label, final String description, final String image, final ICompletionProposal proposal) {
    CompletionProposalBasedModification _completionProposalBasedModification = new CompletionProposalBasedModification(proposal);
    acceptor.accept(issue, label, description, image, _completionProposalBasedModification);
  }
}

==> org.eclipse.n4js.ui.source_0.0.1.201908290301.jar: org/eclipse/n4js/ui/quickfix/AbstractN4JSQuickfixProvider.java <==
/**
 * Copyright (c) 2016 NumberFour AG.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *   NumberFour AG - Initial API and implementation
 */
package org.eclipse.n4js.ui.quickfix;

import com.google.inject.Inject;
import org.apache.log4j.Logger;
import org.eclipse.jface.text.contentassist.ICompletionProposal;
import org.eclipse.n4js.ts.ui.quickfix.TypesQuickfixProvider;
import org.eclipse.n4js.ui.changes.ChangeManager;
import org.eclipse.n4js.ui.quickfix.N4JSQuickfixProvider;
import org.eclipse.n4js.ui.quickfix.N4Modification;
import org.eclipse.n4js.ui.quickfix.N4ModificationWrapper;
import org.eclipse.xtext.ui.editor.model.edit.IModification;
import org.eclipse.xtext.ui.editor.model.edit.ISemanticModification;
import org.eclipse.xtext.ui.editor.quickfix.CompletionProposalBasedModification;
import org.eclipse.xtext.ui.editor.quickfix.IssueResolutionAcceptor;
import org.eclipse.xtext.validation.Issue;
import org.eclipse.xtext.xbase.lib.Exceptions;

@SuppressWarnings("all")
public abstract class AbstractN4JSQuickfixProvider extends TypesQuickfixProvider {
  @Inject
  private ChangeManager changeManager;
  
  /**
   * Logger for this class
   */
  protected static final Logger logger = Logger.getLogger(N4JSQuickfixProvider.class);
  
  @Override
  public void createLinkingIssueResolutions(final Issue issue, final IssueResolutionAcceptor issueResolutionAcceptor) {
    try {
      super.createLinkingIssueResolutions(issue, issueResolutionAcceptor);
    } catch (final Throwable _t) {
      if (_t instanceof Exception) {
        final Exception e = (Exception)_t;
        AbstractN4JSQuickfixProvider.logger.error(e);
      } else {
        throw Exceptions.sneakyThrow(_t);
      }
    }
  }
  
  /**
   * Create an issue resolution based on an {@link N4Modification}. This should be used for most N4JS quick fixes.
   * <p>
   * Note how this method mimics the API in {@link IssueResolutionAcceptor}.
   */
  protected void accept(final IssueResolutionAcceptor acceptor, final Issue issue, final String label, final String description, final String image, final N4Modification modification) {
    N4ModificationWrapper _n4ModificationWrapper = new N4ModificationWrapper(modification, issue, this.changeManager);
    acceptor.accept(issue, label, description, image, _n4ModificationWrapper);
  }
  
  /**
   * This method allows to create quick fixes via the ordinary Xtext quick fix API that are based on an {@link ICompletionProposal}
   * instead of an {@link IModification}, {@link ISemanticModification} or {@link N4Modification}. It is only intended for work-around
   * cases, try to use {@link #accept(IssueResolutionAcceptor,Issue,String,String,String,N4Modification} instead.
   * <p>
   * Note how this method mimics the API in {@link IssueResolutionAcceptor}.
   */
  protected void accept(final IssueResolutionAcceptor acceptor, final Issue issue, final String label, final String description, final String image, final ICompletionProposal proposal) {
    CompletionProposalBasedModification _completionProposalBasedModification = new CompletionProposalBasedModification(proposal);
    acceptor.accept(issue, label, description, image, _completionProposalBasedModification);
  }
}
